.. CosmoToolbox documentation master file, created by
   sphinx-quickstart on Sun Dec  7 09:45:00 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CosmoToolbox's documentation!
========================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   cpplibrary
   pythonmodule



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

